@@ -16,7 +16,8 @@ from covsirphy.util.error import deprecate
 from covsirphy.util.error import SubsetNotFoundError, ScenarioNotFoundError, UnExecutedError
 from covsirphy.util.error import PCRIncorrectPreconditionError, NotInteractiveError, UnExpectedValueError
 from covsirphy.util.error import NotRegisteredMainError, NotRegisteredExtraError
-from covsirphy.util.error import UnExpectedReturnValueError
+from covsirphy.util.error import UnExpectedReturnValueError, NotIncludedError
+from covsirphy.util.error import DBLockedError, NotDBLockedError
 from covsirphy.util.filer import save_dataframe
 from covsirphy.util.argument import find_args
 from covsirphy.util.filer import Filer
@@ -40,10 +41,12 @@ from covsirphy.cleaning.population import PopulationData, Population
 from covsirphy.cleaning.pyramid import PopulationPyramidData
 from covsirphy.cleaning.oxcgrt import OxCGRTData
 from covsirphy.cleaning.pcr_data import PCRData
-from covsirphy.cleaning.covid19datahub import COVID19DataHub
 from covsirphy.cleaning.linelist import LinelistData
 from covsirphy.cleaning.vaccine_data import VaccineData
-from covsirphy.cleaning.dataloader import DataLoader
+from covsirphy.cleaning.mobility_data import MobilityData
+# loading
+from covsirphy.loading.covid19datahub import COVID19DataHub
+from covsirphy.loading.dataloader import DataLoader
 # trend
 from covsirphy.trend.trend_detector import TrendDetector, Trend, ChangeFinder
 from covsirphy.trend.trend_plot import TrendPlot, trend_plot, line_plot_multiple
@@ -101,14 +104,15 @@ __all__ = [
     "SubsetNotFoundError", "ScenarioNotFoundError", "UnExecutedError",
     "PCRIncorrectPreconditionError", "NotInteractiveError",
     "UnExpectedValueError", "NotRegisteredMainError", "NotRegisteredExtraError",
-    "UnExpectedReturnValueError",
+    "UnExpectedReturnValueError", "NotIncludedError", "DBLockedError", "NotDBLockedError",
     # visualization
     "VisualizeBase", "ColoredMap", "LinePlot", "line_plot", "BarPlot", "bar_plot",
     "ComparePlot", "compare_plot", "ScatterPlot", "scatter_plot",
     # cleaning
-    "CleaningBase", "DataLoader", "COVID19DataHub",
-    "JHUData", "CountryData", "PopulationData", "OxCGRTData", "VaccineData",
-    "PopulationPyramidData", "LinelistData", "PCRData", "JapanData", "JHUDataComplementHandler",
+    "CleaningBase", "JHUData", "OxCGRTData", "VaccineData",
+    "PopulationPyramidData", "PCRData", "JapanData", "JHUDataComplementHandler", "MobilityData",
+    # loading
+    "DataLoader",
     # trend
     "TrendDetector", "TrendPlot", "trend_plot",
     # ode
@@ -120,7 +124,8 @@ __all__ = [
     # Deprecated
     "Population", "Word", "jpn_map", "SIRFV", "line_plot_multiple", "ChangeFinder", "Trend",
     "Optimizer", "save_dataframe", "PolicyMeasures", "ODESimulator", "Estimator", "ParamTracker",
-    "PhaseSeries", "PhaseUnit", "MPEstimator",
+    "PhaseSeries", "PhaseUnit", "MPEstimator", "COVID19DataHub", "LinelistData", "PopulationData",
+    "CountryData",
 ]
 
 # Show exceptions in better format if used from command line
