@@ -161,13 +161,19 @@ class Scenario(Term):
 
         Args:
             jhu_data (covsirphy.JHUData or None): object of records
-            population_data (covsirphy.PopulationData or None): PopulationData object
+            population_data (covsirphy.PopulationData or None): PopulationData object (deprecated)
             extras (list[covsirphy.CleaningBase] or None): extra datasets
 
         Raises:
             TypeError: non-data cleaning instance was included
             UnExpectedValueError: instance of un-expected data cleaning class was included as an extra dataset
         """
+        if population_data is not None:
+            warnings.warn(
+                "Scenario.register(population_data) was deprecated because population values are included in JHUData.",
+                DeprecationWarning,
+                stacklevel=2
+            )
         self._data.register(jhu_data=jhu_data, population_data=population_data, extras=extras)
         if self._data.main_satisfied and not self._tracker_dict:
             self.timepoints()
@@ -242,8 +248,7 @@ class Scenario(Term):
         Returns:
             pandas.DataFrame: as the same as JHUData.show_complement()
         """
-        self._data.switch_complement(whether=None, **kwargs)
-        return self._data.show_complement()
+        return self._data.show_complement(**kwargs)
 
     def _convert_variables(self, abbr, candidates):
         """
@@ -447,9 +452,11 @@ class Scenario(Term):
         tracker.define_phase(start, end)
         # Set parameter values
         if None not in set([self._model, self._tau]):
-            param_dict = self._ensure_kwargs(self._model.PARAMETERS, float, **pre_param_dict)
-            param_df = pd.DataFrame(param_dict, index=pd.date_range(start, end))
-            tracker.set_ode(self._model, param_df, self._tau)
+            param_dict = {k: v for (k, v) in pre_param_dict.items() if k in self._model.PARAMETERS}
+            if param_dict:
+                param_dict = self._ensure_kwargs(self._model.PARAMETERS, float, **param_dict)
+                param_df = pd.DataFrame(param_dict, index=pd.date_range(start, end))
+                tracker.set_ode(self._model, param_df, self._tau)
         # Update tracker of self
         self[name] = tracker
         return self
@@ -472,7 +479,7 @@ class Scenario(Term):
         """
         tracker = self._tracker(name, template=template)
         if include_past:
-            self[name] = tracker.remove_phase(self._data.first_date, self._data.last_date)
+            self[name] = PhaseTracker(self._data.records_main(), self.today, self._area)
             return self
         df = tracker.summary()
         future_phases = df.loc[df[self.TENSE] == self.FUTURE].index.tolist()
@@ -527,9 +534,9 @@ class Scenario(Term):
         self[name] = f[last_phase in phases or "last" in phases](start, end)
         return self
 
-    def disable(self, phases, name="Main"):
+    def _reverse(self, phases, name="Main"):
         """
-        The phases will be disabled and removed from summary.
+        The status (enabled/disabled) will be reversed.
 
         Args:
             phase (list[str] or None): phase names or None (all enabled phases)
@@ -543,6 +550,22 @@ class Scenario(Term):
         self[name] = tracker.deactivate(start, end)
         return self
 
+    def disable(self, phases, name="Main"):
+        """
+        The phases will be disabled and removed from summary.
+
+        Args:
+            phase (list[str] or None): phase names or None (all enabled phases)
+            name (str): scenario name
+
+        Returns:
+            covsirphy.Scenario: self
+        """
+        df = self._tracker(name).summary()
+        enabled_phases = df.loc[df[self.TENSE] == self.PAST].index.tolist()
+        rev_phases = [ph for ph in phases if ph in enabled_phases]
+        return self._reverse(phases=rev_phases, name=name)
+
     def enable(self, phases, name="Main"):
         """
         The phases will be enabled and appear in summary.
@@ -554,10 +577,10 @@ class Scenario(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        tracker = self._tracker(name)
-        start, end = tracker.parse_range(phases=phases)
-        self[name] = tracker.define_phase(start, end)
-        return self
+        df = self._tracker(name).summary()
+        enabled_phases = df.loc[df[self.TENSE] == self.PAST].index.tolist()
+        rev_phases = [ph for ph in phases if ph not in enabled_phases]
+        return self._reverse(phases=rev_phases, name=name)
 
     def combine(self, phases, name="Main", **kwargs):
         """
@@ -749,20 +772,24 @@ class Scenario(Term):
         Note:
             If @phases is None, all past phase will be used.
         """
+        self._model = self._ensure_subclass(model, ModelBase, name="model")
         tracker = self._tracker(name)
         if self.TAU in kwargs:
             raise ValueError(
                 "@tau must be specified when scenario = Scenario(), and cannot be specified here.")
-        if phases is not None:
-            df = tracker.summary()
-            all_phases = df.loc[df[self.TENSE] == self.PAST].index.tolist()
-            self.disable(phases=all_phases, name=name)
-            self.enable(phases, name=name)
-        self._model = self._ensure_subclass(model, ModelBase, name="model")
-        self._tau = tracker.estimate(self._model, tau=self._tau, **kwargs)
-        if phases is not None:
-            self.enable(phases=all_phases, name=name)
-        self[name] = tracker
+        if phases is None:
+            self._tau = self[name].estimate(self._model, tau=self._tau, **kwargs)
+            return
+        df = tracker.summary()
+        all_phases = df.loc[df[self.TENSE] == self.PAST].index.tolist()
+        self.disable(phases=all_phases, name=name)
+        handler_kwargs = {"n_jobs": 1}
+        handler_kwargs.update(kwargs)
+        for ph in phases:
+            self._reverse(phases=[ph], name=name)
+            self._tau = self[name].estimate(self._model, tau=self._tau, **handler_kwargs)
+            self._reverse(phases=[ph], name=name)
+        self.enable(phases=all_phases, name=name)
 
     @deprecate("Scenario.phase_estimator()", version="2.19.1-delta-fu1")
     def phase_estimator(self, **kwargs):
@@ -1001,7 +1028,8 @@ class Scenario(Term):
         # Add actual records, if necessary
         if with_actual:
             df = self._data.records(extras=False)
-            df.insert(0, self.SERIES, self.ACTUAL)
+            if self.SERIES not in df:
+                df.insert(0, self.SERIES, self.ACTUAL)
             append(df)
         # Concat dataframes
         track_df = pd.concat(dataframes, axis=0, ignore_index=True, sort=False)
@@ -1253,7 +1281,11 @@ class Scenario(Term):
                 - None: Scenario.estimate_delay() calculate automatically
             removed_cols (list[str] or None): list of variables to remove from X dataset or None (indicators used to estimate delay period)
             metric (str): metric name
-            kwargs: keyword arguments of sklearn.model_selection.train_test_split(), RegressorHandler.fit() and Scenario.fit_accuracy()
+            kwargs: keyword arguments of
+                - sklearn.model_selection.train_test_split(),
+                - RegressionHandler.feature_engineering(),
+                - RegressorHandler.fit() and
+                - Scenario.fit_accuracy()
 
         Raises:
             covsirphy.UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
@@ -1309,7 +1341,9 @@ class Scenario(Term):
             # Use specified delay value
             delay = self._ensure_natural_int(delay, name="delay")
         # Fit regression models
-        handler = RegressionHandler(data=data, model=self._model, delay=delay, **kwargs)
+        handler = RegressionHandler(data=data, model=self._model, **kwargs)
+        handler.feature_engineering(
+            delay=delay, **find_args(RegressionHandler.feature_engineering, **kwargs))
         handler.fit(metric=metric, **find_args(RegressionHandler.fit, **kwargs))
         self._reghandler_dict[name] = handler
         # Accuracy
